==> Roberts2005Annotation.db_2.2.0.tar.gz: Roberts2005Annotation.db/man/Roberts2005Annotation_dbconn.Rd <==
\name{Roberts2005Annotation_dbconn}

\alias{Roberts2005Annotation_dbconn}
\alias{Roberts2005Annotation_dbfile}
\alias{Roberts2005Annotation_dbschema}
\alias{Roberts2005Annotation_dbInfo}


\title{Collect information about the package annotation DB}

\description{
  Some convenience functions for getting a connection object to (or collecting
  information about) the package annotation DB.
}

\usage{
  Roberts2005Annotation_dbconn()
  Roberts2005Annotation_dbfile()
  Roberts2005Annotation_dbschema(file="", show.indices=FALSE)
  Roberts2005Annotation_dbInfo()
}

\arguments{
  \item{file}{
    A connection, or a character string naming the file to print to (see
    the \code{file} argument of the \code{\link[base]{cat}} function for
    the details).
  }
  \item{show.indices}{
    The CREATE INDEX statements are not shown by default.
    Use \code{show.indices=TRUE} to get them.
  }
}

\details{
  \code{Roberts2005Annotation_dbconn} returns a connection object to the package
  annotation DB.
  IMPORTANT: Don't call \code{\link[DBI]{dbDisconnect}} on the connection
  object returned by \code{Roberts2005Annotation_dbconn} or you will
  break all the \code{\link[AnnotationDbi]{AnnDbObj}} objects defined in this package!

  \code{Roberts2005Annotation_dbfile} returns the path (character string) to the
  package annotation DB (this is an SQLite file).

  \code{Roberts2005Annotation_dbschema} prints the schema definition of the
  package annotation DB.

  \code{Roberts2005Annotation_dbInfo} prints other information about the package
  annotation DB.
}

\value{
  \code{Roberts2005Annotation_dbconn}: a DBIConnection object representing an open
  connection to the package annotation DB.

  \code{Roberts2005Annotation_dbfile}: a character string with the path to the
  package annotation DB.

  \code{Roberts2005Annotation_dbschema}: none (invisible \code{NULL}).

  \code{Roberts2005Annotation_dbInfo}: none (invisible \code{NULL}).
}

\seealso{
  \code{\link[DBI]{dbGetQuery}},
  \code{\link[DBI]{dbConnect}},
  \code{\link[AnnotationDbi]{dbconn}},
  \code{\link[AnnotationDbi]{dbfile}},
  \code{\link[AnnotationDbi]{dbschema}},
  \code{\link[AnnotationDbi]{dbInfo}}
}

\examples{
  ## Count the number of rows in the "probes" table:
  dbGetQuery(Roberts2005Annotation_dbconn(), "SELECT COUNT(*) FROM probes")

  ## The connection object returned by Roberts2005Annotation_dbconn() was created with:
  dbConnect(SQLite(), dbname=Roberts2005Annotation_dbfile(), cache_size=64000, synchronous=0)

  Roberts2005Annotation_dbschema()

  Roberts2005Annotation_dbInfo()
}

\keyword{utilities}
\keyword{datasets}

==> Roberts2005Annotation.db_2.4.5.tar.gz: Roberts2005Annotation.db/man/Roberts2005Annotation_dbconn.Rd <==

\name{Roberts2005Annotation_dbconn}

\alias{Roberts2005Annotation_dbconn}
\alias{Roberts2005Annotation_dbfile}
\alias{Roberts2005Annotation_dbschema}
\alias{Roberts2005Annotation_dbInfo}


\title{Collect information about the package annotation DB}

\description{
  Some convenience functions for getting a connection object to (or collecting
  information about) the package annotation DB.
}

\usage{
  Roberts2005Annotation_dbconn()
  Roberts2005Annotation_dbfile()
  Roberts2005Annotation_dbschema(file="", show.indices=FALSE)
  Roberts2005Annotation_dbInfo()
}

\arguments{
  \item{file}{
    A connection, or a character string naming the file to print to (see
    the \code{file} argument of the \code{\link[base]{cat}} function for
    the details).
  }
  \item{show.indices}{
    The CREATE INDEX statements are not shown by default.
    Use \code{show.indices=TRUE} to get them.
  }
}

\details{
  \code{Roberts2005Annotation_dbconn} returns a connection object to the
  package annotation DB.  IMPORTANT: Don't call
  \code{\link[DBI:dbConnect]{dbDisconnect}} on the connection object
  returned by \code{Roberts2005Annotation_dbconn} or you will break all the
  \code{\link[AnnotationDbi:AnnDbObj-class]{AnnDbObj}} objects defined
  in this package!

  \code{Roberts2005Annotation_dbfile} returns the path (character string) to the
  package annotation DB (this is an SQLite file).

  \code{Roberts2005Annotation_dbschema} prints the schema definition of the
  package annotation DB.

  \code{Roberts2005Annotation_dbInfo} prints other information about the package
  annotation DB.
}

\value{
  \code{Roberts2005Annotation_dbconn}: a DBIConnection object representing an
  open connection to the package annotation DB.

  \code{Roberts2005Annotation_dbfile}: a character string with the path to the
  package annotation DB.

  \code{Roberts2005Annotation_dbschema}: none (invisible \code{NULL}).

  \code{Roberts2005Annotation_dbInfo}: none (invisible \code{NULL}).
}

\seealso{
  \code{\link[DBI:dbSendQuery]{dbGetQuery}},
  \code{\link[DBI:dbConnect]{dbConnect}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbconn}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbfile}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbschema}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbInfo}}
}

\examples{
  ## Count the number of rows in the "probes" table:
  dbGetQuery(Roberts2005Annotation_dbconn(), "SELECT COUNT(*) FROM probes")

  ## The connection object returned by Roberts2005Annotation_dbconn() was
  ## created with:
  dbConnect(SQLite(), dbname=Roberts2005Annotation_dbfile(), cache_size=64000,
  synchronous=0)

  Roberts2005Annotation_dbschema()

  Roberts2005Annotation_dbInfo()
}

\keyword{utilities}
\keyword{datasets}
